CAT: Coral Annotation Tool

⏳
Loading Project
Initializing...

#### 📂 Load Project

Upload your project JSON file to begin annotating.

#### 🗺️ Map Layers

No Site
▼
📷 Map Files ▼
⚙️ Layer Controls ▼
✏️ Annotations ▼
Opacity: 80%
Line Width: 7px
Show Species Labels

#### 📊 Statistics

Total: 0
Lines: 0
Boxes: 0
Polygons: 0

### ✏️ Annotation Form

Press `Ctrl+S` to save
▼
Analyst *
Year *
Mission ID *
Site *
Transect
Segment
Seg Length
Seg Width
Species (type to search)
Morphology
No Colony
Juvenile
Remnant
Ex. Bound
Old Dead %
RD Cause 1
RD 1 %
RD Cause 2
RD 2 %
RD Cause 3
RD 3 %
Condition 1
Extent 1 %
Severity 1
Condition 2
Extent 2 %
Severity 2
Condition 3
Extent 3 %
Severity 3

### 📋 Annotations (0)

▼

ID | Type | Species | Analyst | Site | Year | Mission | Segment | Transect | Morph | Old Dead % | Actions
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
No annotations yet - draw on the map to create one

Loading...

### ✏️ Edit Annotation #